<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<!-- ====================================================================== -->
	<!-- document section -->
	<!-- ====================================================================== -->
	<xsl:template match="/">
	    <!-- checks if this is the included document to avoid neverending loop -->
	    <xsl:choose>
            <xsl:when test="site/book">
                    <xsl:apply-templates />
            </xsl:when>
            <xsl:otherwise>
		     <html>
		         <head>
    			        <title>
				       <xsl:value-of select="document/header/title"/>
			        </title>
			    </head>
			    <body>
			        <xsl:apply-templates/>
			    </body>
		      </html>                
            </xsl:otherwise>            
        </xsl:choose>
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- header section -->
	<!-- ====================================================================== -->
	<xsl:template match="header">
		<!-- ignore on general document -->
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- body section -->
	<!-- ====================================================================== -->
	<xsl:template match="s1">
	    <h1><xsl:value-of select="@title"/></h1>
 	    <xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="s2">
	    <h2><xsl:value-of select="@title"/></h2>
 	    <xsl:apply-templates/>		
	</xsl:template>
	<xsl:template match="s3">
	    <h3><xsl:value-of select="@title"/></h3>
 	    <xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="s4">
	    <h4><xsl:value-of select="@title"/></h4>
 	    <xsl:apply-templates/>	
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- footer section -->
	<!-- ====================================================================== -->
	<xsl:template match="footer">
		<!-- ignore on general documents -->
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- paragraph section -->
	<!-- ====================================================================== -->
	<xsl:template match="p">
		<p>
			<xsl:apply-templates />
		</p>
	</xsl:template>
	
	<xsl:template match="source">
        <pre class="code"><xsl:apply-templates /></pre>
	</xsl:template>	
	
	<xsl:template match="note">
         <div class="frame note">
             <div class="label"><xsl:value-of select="@label"/></div>
             <div class="content"><xsl:apply-templates /></div>
         </div>
	</xsl:template>

	<xsl:template match="warning">
	    <div class="frame warning">
             <div class="label"><xsl:value-of select="@label"/></div>
             <div class="content"><xsl:apply-templates /></div>
         </div>	
	</xsl:template>
	
	<xsl:template match="fixme">
		<!-- ignore on documentation -->
	    <div class="frame fixme">
             <div class="label"><xsl:value-of select="@label"/></div>
             <div class="content"><xsl:apply-templates /></div>
         </div>			
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- list section -->
	<!-- ====================================================================== -->
	<xsl:template match="ul|ol|dl">
		<xsl:copy>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="li|dt|dd">
		<xsl:copy>
			<xsl:apply-templates/>
          </xsl:copy>
      </xsl:template>
      <!-- FIXME (KP): What's this? -->
	<xsl:template match="sl">
		<ul>
			<xsl:apply-templates/>
		</ul>
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- table section -->
	<!-- ====================================================================== -->
	<xsl:template match="table">
		<table class="table" cellspacing="1" cellpadding="4">
			<caption><xsl:value-of select="caption"/></caption>
			<xsl:apply-templates/>
		</table>
	</xsl:template>
	<xsl:template match="tr|th|td">
		<xsl:copy>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	
	<!-- FIXME (KP): Do we need this? -->
	<xsl:template match="tn">
		<td><xsl:copy-of select="@*"/>
		    &#160;
		</td>
	</xsl:template>
	<xsl:template match="caption">
		<!-- ignore since already used -->
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- markup section -->
	<!-- ====================================================================== -->
	<xsl:template match="strong|em|sub|sup|code">
		<xsl:copy><xsl:apply-templates/></xsl:copy>
	</xsl:template>
	<xsl:template match="hi">
		<span class="highlight"><xsl:apply-templates/></span>
	</xsl:template>	
	<!-- ====================================================================== -->
	<!-- images section -->
	<!-- ====================================================================== -->
	<xsl:template match="figure">
         <div align="center"><img class="figure" src="{@src}"/></div>
	</xsl:template>
	<!-- FIXME (KP): Do we need this one? -->
	<xsl:template match="img">
		<img src="{@src}" alt="{@alt}" />
	</xsl:template>
	<xsl:template match="icon">
		<img class="icon" src="{@src}" alt="{@alt}" align="absmiddle"/>
	</xsl:template>
 	<!-- ====================================================================== -->
	<!-- links section -->
	<!-- ====================================================================== -->
	<xsl:template match="link">
		<a href="{@href}"><xsl:apply-templates/></a>
	</xsl:template>
	<xsl:template match="anchor">
		<a name="{@id}" />
	</xsl:template>	
	<!-- FIXME (KP): Do we need following link types? -->
	<xsl:template match="connect">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="jump">
		<a href="{@href}#{@anchor}"><xsl:apply-templates/></a>
	</xsl:template>
	<xsl:template match="fork">
		<a href="{@href}" target="_blank"><xsl:apply-templates/></a>
	</xsl:template>
	<!-- ====================================================================== -->
	<!-- specials section -->
	<!-- ====================================================================== -->
	<xsl:template match="br">
		<br/>
	</xsl:template>
</xsl:stylesheet>
