<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html [
    <!ENTITY nbsp "&#160;">
    <!ENTITY copy "&#0169;">
    <!ENTITY laquo "&#0171;">
    <!ENTITY raquo "&#0187;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="index2html.xsl"/>
    <xsl:import href="document2html.xsl"/>
    <xsl:output method="html" />
    <xsl:param name="page-index">1</xsl:param>
    <xsl:param name="page-count">1</xsl:param>    
    <xsl:param name="page-name">page</xsl:param>    
    <!-- Used for path menu creation 
FIXME (KP): Is it possible to use xsl:key?
-->
    <xsl:variable name="path-items" select="/site/index//*[@current]"/>
    <xsl:template match="site">
        <html>
            <head>
                <title>
                    <xsl:value-of select="concat(header/title, ' - ', book/document/header/title)"/>
                </title>
                <link rel="stylesheet" href="page.css" type="text/css"/>
                <xsl:apply-templates select="book/document/header/authors/person"/>
            </head>
            <body>
                <xsl:call-template name="nav-path"/>
                <xsl:call-template name="page-top"/>
                <xsl:call-template name="tabs"/>
                <div class="topline">&nbsp;</div>
                <table cellspacing="0" cellpadding="0" summary="the content pane">
                    <tr>
                        <td width="5" class="navbar">&nbsp;</td>
                        <td rowspan="2" valign="top" nowrap="nowrap">
                            <xsl:apply-templates select="index"/>
                        </td>
                        <td valign="top" class="navbar" align="left">Page <xsl:value-of select="$page-index"/> of <xsl:value-of select="$page-count"/></td>
                        <td width="*" valign="top" class="navbar" align="right">
                        <!-- FIXME (KP) there must be no dependency on fle extension -->
                            <xsl:if test="$page-index &gt; 1">
                                <a href="{$page-name}[{$page-index - 1}].html">&laquo; prev</a>
                            </xsl:if>
                            <strong><xsl:number format=" [1] " value="$page-index"/></strong>
                            <!-- FIXME (KP) there must be no dependency on fle extension -->
                            <xsl:if test="$page-index &lt; $page-count">
                                <a href="{$page-name}[{$page-index + 1}].html">next &raquo;</a>
                            </xsl:if>
                        </td>
                    </tr>
                    <tr>
                        <td>&nbsp;</td>
                        <td colspan="2" valign="top" class="content">
                            <xsl:call-template name="page-title" />
                            <xsl:apply-templates select="book/document"/>
                        </td>
                    </tr>
                    <tr>
                        <td>&nbsp;</td>
                        <td>&nbsp;</td>
                    </tr>
                </table>
                <xsl:call-template name="copyright"/>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="person">
        <meta name="author" content="{@name}"/>
    </xsl:template>
    <!-- Named templates -->
    <!-- Path menu construction -->
    <xsl:template name="nav-path">
        <div class="path">
            <xsl:for-each select="$path-items">
                <xsl:choose>
                    <xsl:when test="position()!=last()">
                        <a href="{@uri}">
                            <xsl:value-of select="@label"/>
                        </a>&nbsp;&gt;&nbsp;</xsl:when>
                    <xsl:otherwise>
                        <span class="current">
                            <xsl:value-of select="@label"/>
                            <xsl:if test="$page-index != 0">
                                <xsl:number format=" [1]" value="$page-index"/>
                            </xsl:if>
                        </span>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </div>
    </xsl:template>
    <!-- Page top creation -->
    <xsl:template name="page-top">
        <table class="top" cellspacing="0" cellpadding="0" summary="the top bar">
            <tr>
                <td>
                    <img src="images/biglogo.gif"/>
                </td>
                <td valign="middle" align="center" width="100%">
                    <img src="images/cocoon.gif"/>
                </td>
                <td valign="top" nowrap="nowrap" height="69">
                    <div class="search">
                        <form method="get" action="http://www.google.com/search" onsubmit="q.value = query.value + ' site:xml.apache.org'">
                            <input type="hidden" name="q"/>
                            <input type="text" id="query" size="15"/>&nbsp;<input type="button" value="Search" name="Search"/>
                            <br/>
                            <input type="radio" name="web" value="web"/>web site&nbsp;<input type="radio" name="mail" value="mail"/>mail lists
        </form>
                    </div>
                </td>
            </tr>
        </table>
    </xsl:template>
    <xsl:template name="tabs">
        <div class="tabs">
            <xsl:for-each select="index/book">
                <xsl:choose>
                    <xsl:when test="@current">
                        <span class="current" title="{@uri}"><xsl:value-of select="@label"/></span><xsl:text>
                        </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <span class="tab"><a href="{@uri}"><xsl:value-of select="@label"/></a></span><xsl:text>
                        </xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </div>
    </xsl:template>
    
    <xsl:template name="page-title">
        <table>
          <tr> 
            <td valign="middle"> 
              <h2><xsl:value-of select="$path-items[position()=last()]/@label"/></h2>
            </td>
            <td align="center" width="80" nowrap="nowrap"><a href="" class="dida"><img src="images/singlepage.gif"/><br/>
              single page<br/>
              version</a></td>
            <td align="center" width="80" nowrap="nowrap"><a href="" class="dida"><img src="images/printer.gif"/><br/>
              print-friendly<br/>
              version</a></td>
          </tr>
        </table>    
    </xsl:template>
    
    <xsl:template name="copyright">
        <div class="copyright">
Copyright &copy; 1999-2002 <a href="http://www.apache.org/">Apache Software Foundation</a>. All Rights Reserved.
    </div>
    </xsl:template>
</xsl:stylesheet>
